@@ -1,5 +1,5 @@
 package Catalyst::View::JavaScript::Minifier::XS;
-our $VERSION = '0.092790';
+our $VERSION = '0.092800';
 
 
 
@@ -111,7 +111,7 @@ __END__
 
 =head1 VERSION
 
-version 0.092790
+version 0.092800
 
 =head1 NAME
 
@@ -119,20 +119,20 @@ Catalyst::View::JavaScript::Minifier::XS - Concenate and minify your JavaScript
 
 =head1 SYNOPSIS
 
-    # creating MyApp::View::JavaScript
-    ./script/myapp_create.pl view JavaScript JavaScript::Minifier::XS
+   # creating MyApp::View::JavaScript
+   ./script/myapp_create.pl view JavaScript JavaScript::Minifier::XS
 
-	# in your controller file, as an action
-    sub js : Local {
-		my ( $self, $c ) = @_;
+   # in your controller file, as an action
+   sub js : Local {
+      my ( $self, $c ) = @_;
 
-		$c->stash->{js} = [qw/script1 script2/]; # loads root/js/script1.js and root/js/script2.js
+      $c->stash->{js} = [qw/script1 script2/]; # loads root/js/script1.js and root/js/script2.js
 
-		$c->forward("View::JavaScript");
-    }
+      $c->forward('View::JavaScript');
+   }
 
-	# in your html template use
-	<script type="text/javascript" src="/js"></script>
+   # in your html template use
+   <script type="text/javascript" src="/js"></script>
 
 =head1 DESCRIPTION
 
